/*

EditableList.js

Copyright (c) 2006 Scue

www.scue.co.uk (www.scue.co.uk/widgets/)
info@scue.co.uk
developer: aidan kane (aidan@scue.co.uk)

see LICENSE for details of the license

*/


// EditableList class provides a wrapper for dropdown lists that can be typed into

function EditableList()
{
	// references to the html elements
	this.texbox = null;
	this.dropdown = null;

	// list details
	this.maxListLength = 5;
	this.currentList = new Array();

	// option for clearing the list
	this.clearText = 'clear list...';
}

EditableList.prototype =
{
	init : function(textbox,dropdown,list,newClearText,textboxText)
	{
		this.textbox = textbox;
		if (textboxText) this.textbox.value = textboxText;
		this.dropdown = dropdown;

		if (list.length > 0)
		{
			this.currentList = list;
			// todo: do this using normal array operations
			
			while (this.currentList.length > 5)
			{
				var useless = this.currentList.pop();
			}
			this.updateDropdownFromList();

			this.textbox.value = list[0];
		}
		this.clearText = newClearText;

		this.updateDropdownFromList();
	},

	// add current selection to list
	updateDropdownFromText : function()
	{
		var currentText = this.textbox.value;

		if (currentText.length > 0)
		{
			var pos = this.findPositionOf(currentText);

			// this item might already be in the list
			if (pos > -1)
			{
				// remove it so we can put it at the top of the list
				this.currentList.splice(pos,1);
			}
			else if (this.currentList.length == this.maxListLength)
			{
				// make room for it
				this.currentList.pop();
			}

			// add the item to the top of the list
			this.currentList.unshift(currentText);

			// todo: plain lazy - implement this properly
			this.updateDropdownFromList();
		}
	},

	// when changed we need to either update the texbox or clear the list
	dropdownChanged : function()
	{
		if (this.dropdown.value == -1)
		{
			// clear the list
			this.currentList = new Array();
			this.updateDropdownFromList();
			// todo: clear the textbox too???
		}
		else if (this.dropdown.value != '')
		{
			this.textbox.value = this.dropdown.options[this.dropdown.selectedIndex].text;
		}
	},

	// copies the array to the interface
	updateDropdownFromList : function()
	{
		this.dropdown.options.length = 0;
		for (var i = 0; i < this.currentList.length; i++)
		{
			this.addOptionToDropdown(i,this.currentList[i]);
		}
		this.addOptionToDropdown("","--------");
		this.addOptionToDropdown(-1,this.clearText);
	},

	setValue : function(text)
	{
		this.textbox.value = text;
	},

	getValue : function()
	{
		return this.textbox.value;
	},
	
	getList : function()
	{
		return this.currentList;	
	},

	// returns the position of the first occurence of val in list (-1 if not found)
	findPositionOf : function(val)
	{
		for (var i = 0; i < this.currentList.length; i++)
		{
			if (this.currentList[i] == val)
			{
				return i;
			}
		}	
		return -1;
	},

	// adds an option to the end of our dropdown
	addOptionToDropdown : function(value,text)
	{
		var newOpt = new Option;
		newOpt.value = value;
		newOpt.text = text;
		this.dropdown.options[this.dropdown.length] = newOpt;
	}
}
